==> TechRebornJEI-19.3.5-sources.jar: thelm/techrebornjei/addon/advancedreborn/AdvancedRebornJEI.java <==
package thelm.techrebornjei.addon.advancedreborn;

import mezz.jei.api.IModPlugin;
import mezz.jei.api.constants.RecipeTypes;
import mezz.jei.api.recipe.RecipeType;
import mezz.jei.api.registration.IGuiHandlerRegistration;
import mezz.jei.api.registration.IRecipeCatalystRegistration;
import mezz.jei.api.registration.IRecipeCategoryRegistration;
import mezz.jei.api.registration.IRecipeRegistration;
import ml.pkom.advancedreborn.Blocks;
import ml.pkom.advancedreborn.Recipes;
import ml.pkom.advancedreborn.gui.GuiCanningMachine;
import ml.pkom.advancedreborn.gui.GuiCentrifugalExtractor;
import ml.pkom.advancedreborn.gui.GuiInductionFurnace;
import ml.pkom.advancedreborn.gui.GuiRotaryGrinder;
import ml.pkom.advancedreborn.gui.GuiSingularityCompressor;
import net.minecraft.class_1799;
import net.minecraft.class_1863;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import reborncore.common.crafting.RebornRecipe;
import thelm.techrebornjei.TechRebornJEI;
import thelm.techrebornjei.gui.render.RecipeClickAreaRenderable;
import thelm.techrebornjei.recipe.category.TwoItemToItemRecipeCategory;

public class AdvancedRebornJEI implements IModPlugin {

	public static final class_2960 UID = new class_2960("techrebornjei:advancedreborn");

	public static final RecipeType<RebornRecipe> CANNING_MACHINE = TechRebornJEI.createRecipeType(Recipes.CANNING_MACHINE);

	@Override
	public class_2960 getPluginUid() {
		return UID;
	}

	@Override
	public void registerCategories(IRecipeCategoryRegistration registration) {
		registration.addRecipeCategories(new TwoItemToItemRecipeCategory<>(CANNING_MACHINE));
	}

	@Override
	public void registerRecipes(IRecipeRegistration registration) {
		class_1863 recipeManager = class_310.method_1551().field_1687.method_8433();
		registration.addRecipes(CANNING_MACHINE, recipeManager.method_30027(Recipes.CANNING_MACHINE));
	}

	@Override
	public void registerRecipeCatalysts(IRecipeCatalystRegistration registration) {
		registration.addRecipeCatalyst(new class_1799(Blocks.CANNING_MACHINE), CANNING_MACHINE);

		registration.addRecipeCatalyst(new class_1799(Blocks.ROTARY_GRINDER), TechRebornJEI.GRINDER);
		registration.addRecipeCatalyst(new class_1799(Blocks.CENTRIFUGAL_EXTRACTOR), TechRebornJEI.EXTRACTOR);
		registration.addRecipeCatalyst(new class_1799(Blocks.SINGULARITY_COMPRESSOR), TechRebornJEI.COMPRESSOR);

		registration.addRecipeCatalyst(new class_1799(Blocks.INDUCTION_FURNACE), RecipeTypes.SMELTING);
	}

	@Override
	public void registerGuiHandlers(IGuiHandlerRegistration registration) {
		registration.addRecipeClickArea(GuiCanningMachine.class, 158, 5, 12, 12, CANNING_MACHINE);

		registration.addRecipeClickArea(GuiRotaryGrinder.class, 158, 5, 12, 12, TechRebornJEI.GRINDER);
		registration.addRecipeClickArea(GuiCentrifugalExtractor.class, 158, 5, 12, 12, TechRebornJEI.EXTRACTOR);
		registration.addRecipeClickArea(GuiSingularityCompressor.class, 158, 5, 12, 12, TechRebornJEI.COMPRESSOR);

		registration.addRecipeClickArea(GuiInductionFurnace.class, 158, 5, 12, 12, RecipeTypes.SMELTING);

		RecipeClickAreaRenderable.addEntry(GuiCanningMachine.class);

		RecipeClickAreaRenderable.addEntry(GuiRotaryGrinder.class);
		RecipeClickAreaRenderable.addEntry(GuiCentrifugalExtractor.class);
		RecipeClickAreaRenderable.addEntry(GuiSingularityCompressor.class);

		RecipeClickAreaRenderable.addEntry(GuiInductionFurnace.class);
	}
}

==> TechRebornJEI-20.2.8-sources.jar: thelm/techrebornjei/addon/advancedreborn/AdvancedRebornJEI.java <==
package thelm.techrebornjei.addon.advancedreborn;

import mezz.jei.api.IModPlugin;
import mezz.jei.api.constants.RecipeTypes;
import mezz.jei.api.recipe.RecipeType;
import mezz.jei.api.registration.IGuiHandlerRegistration;
import mezz.jei.api.registration.IRecipeCatalystRegistration;
import mezz.jei.api.registration.IRecipeCategoryRegistration;
import mezz.jei.api.registration.IRecipeRegistration;
import mezz.jei.api.registration.ISubtypeRegistration;
import ml.pkom.advancedreborn.Blocks;
import ml.pkom.advancedreborn.Items;
import ml.pkom.advancedreborn.Recipes;
import ml.pkom.advancedreborn.gui.GuiCanningMachine;
import ml.pkom.advancedreborn.gui.GuiCentrifugalExtractor;
import ml.pkom.advancedreborn.gui.GuiInductionFurnace;
import ml.pkom.advancedreborn.gui.GuiRotaryGrinder;
import ml.pkom.advancedreborn.gui.GuiSingularityCompressor;
import net.fabricmc.fabric.api.itemgroup.v1.ItemGroupEvents;
import net.minecraft.class_1799;
import net.minecraft.class_1863;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_8786;
import reborncore.common.crafting.RebornRecipe;
import thelm.techrebornjei.TechRebornJEI;
import thelm.techrebornjei.addon.advancedreborn.event.CreativeTabEventHandler;
import thelm.techrebornjei.gui.render.RecipeClickAreaRenderable;
import thelm.techrebornjei.ingredient.subtype.EnergyItemSubtypeInterpreter;
import thelm.techrebornjei.recipe.category.TwoItemToItemRecipeCategory;

public class AdvancedRebornJEI implements IModPlugin {

	public static final class_2960 UID = new class_2960("techrebornjei:advancedreborn");

	public static final RecipeType<class_8786<RebornRecipe>> CANNING_MACHINE = RecipeType.createFromVanilla(Recipes.CANNING_MACHINE);

	public AdvancedRebornJEI() {
		ItemGroupEvents.MODIFY_ENTRIES_ALL.register(new CreativeTabEventHandler());
	}

	@Override
	public class_2960 getPluginUid() {
		return UID;
	}

	@Override
	public void registerItemSubtypes(ISubtypeRegistration registration) {
		EnergyItemSubtypeInterpreter energy = new EnergyItemSubtypeInterpreter();
		registration.registerSubtypeInterpreter(Items.ADVANCED_BATTERY, energy);
		registration.registerSubtypeInterpreter(Items.ADVANCED_BATTERY_2, energy);
		registration.registerSubtypeInterpreter(Items.ADVANCED_BATTERY_3, energy);
		registration.registerSubtypeInterpreter(Items.ADVANCED_BATTERY_4, energy);
		registration.registerSubtypeInterpreter(Items.ADVANCED_BATTERY_5, energy);
		registration.registerSubtypeInterpreter(Items.NANO_SUIT_HELMET, energy);
		registration.registerSubtypeInterpreter(Items.NANO_SUIT_BODY_ARMOR, energy);
		registration.registerSubtypeInterpreter(Items.NANO_SUIT_LEGGINGS, energy);
		registration.registerSubtypeInterpreter(Items.NANO_SUIT_BOOTS, energy);
		registration.registerSubtypeInterpreter(Items.BATPACK_4, energy);
		registration.registerSubtypeInterpreter(Items.BATPACK_16, energy);
		registration.registerSubtypeInterpreter(Items.BATPACK_64, energy);
		registration.registerSubtypeInterpreter(Items.BATPACK_128, energy);
	}

	@Override
	public void registerCategories(IRecipeCategoryRegistration registration) {
		registration.addRecipeCategories(new TwoItemToItemRecipeCategory<>(CANNING_MACHINE));
	}

	@Override
	public void registerRecipes(IRecipeRegistration registration) {
		class_1863 recipeManager = class_310.method_1551().field_1687.method_8433();
		registration.addRecipes(CANNING_MACHINE, recipeManager.method_30027(Recipes.CANNING_MACHINE));
	}

	@Override
	public void registerRecipeCatalysts(IRecipeCatalystRegistration registration) {
		registration.addRecipeCatalyst(new class_1799(Blocks.CANNING_MACHINE), CANNING_MACHINE);

		registration.addRecipeCatalyst(new class_1799(Blocks.ROTARY_GRINDER), TechRebornJEI.GRINDER);
		registration.addRecipeCatalyst(new class_1799(Blocks.CENTRIFUGAL_EXTRACTOR), TechRebornJEI.EXTRACTOR);
		registration.addRecipeCatalyst(new class_1799(Blocks.SINGULARITY_COMPRESSOR), TechRebornJEI.COMPRESSOR);

		registration.addRecipeCatalyst(new class_1799(Blocks.INDUCTION_FURNACE), RecipeTypes.SMELTING);
	}

	@Override
	public void registerGuiHandlers(IGuiHandlerRegistration registration) {
		registration.addRecipeClickArea(GuiCanningMachine.class, 158, 5, 12, 12, CANNING_MACHINE);

		registration.addRecipeClickArea(GuiRotaryGrinder.class, 158, 5, 12, 12, TechRebornJEI.GRINDER);
		registration.addRecipeClickArea(GuiCentrifugalExtractor.class, 158, 5, 12, 12, TechRebornJEI.EXTRACTOR);
		registration.addRecipeClickArea(GuiSingularityCompressor.class, 158, 5, 12, 12, TechRebornJEI.COMPRESSOR);

		registration.addRecipeClickArea(GuiInductionFurnace.class, 158, 5, 12, 12, RecipeTypes.SMELTING);

		RecipeClickAreaRenderable.addEntry(GuiCanningMachine.class);

		RecipeClickAreaRenderable.addEntry(GuiRotaryGrinder.class);
		RecipeClickAreaRenderable.addEntry(GuiCentrifugalExtractor.class);
		RecipeClickAreaRenderable.addEntry(GuiSingularityCompressor.class);

		RecipeClickAreaRenderable.addEntry(GuiInductionFurnace.class);
	}
}
